@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2009, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -20,6 +20,10 @@ import java.util.Date;
 import java.util.logging.LogManager;
 
 import ch.qos.logback.classic.jul.JULHelper;
+import ch.qos.logback.core.pattern.parser.Parser;
+import ch.qos.logback.core.pattern.parser.ScanException;
+import ch.qos.logback.core.status.Status;
+import ch.qos.logback.core.util.CachingDateFormatter;
 import ch.qos.logback.core.util.StatusPrinter;
 import org.junit.Ignore;
 import org.junit.Test;
@@ -48,6 +52,7 @@ public class JoranConfiguratorTest {
   LoggerContext loggerContext = new LoggerContext();
   Logger logger = loggerContext.getLogger(this.getClass().getName());
   Logger root = loggerContext.getLogger(Logger.ROOT_LOGGER_NAME);
+  StatusChecker sc = new StatusChecker(loggerContext);
 
   void configure(String file) throws JoranException {
     JoranConfigurator jc = new JoranConfigurator();
@@ -85,7 +90,7 @@ public class JoranConfiguratorTest {
     configure(ClassicTestConstants.JORAN_INPUT_PREFIX + "additivity.xml");
     Logger logger = loggerContext.getLogger("additivityTest");
     assertFalse(logger.isAdditive());
-   }
+  }
 
   @Test
   public void rootLoggerLevelSettingBySystemProperty() throws JoranException {
@@ -297,8 +302,8 @@ public class JoranConfiguratorTest {
 
     StatusPrinter.print(loggerContext);
     StatusChecker checker = new StatusChecker(loggerContext);
-    assertTrue(checker.isErrorFree());
-    assertTrue(checker.containsMatch("Resetting and reconfiguring context"));
+    assertTrue(checker.isErrorFree(0));
+    assertTrue(checker.containsMatch("Will reset and reconfigure context"));
   }
 
   @Test
@@ -311,8 +316,8 @@ public class JoranConfiguratorTest {
 
     String r = loggerContext.getProperty("testTimestamp");
     assertNotNull(r);
-    SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM");
-    String expected = sdf.format(new Date());
+    CachingDateFormatter sdf = new CachingDateFormatter("yyyy-MM");
+    String expected = sdf.format(System.currentTimeMillis());
     assertEquals("expected \"" + expected + "\" but got " + r, expected, r);
   }
 
@@ -331,7 +336,7 @@ public class JoranConfiguratorTest {
     assertEquals("UTF-8", encoder.getCharset().displayName());
 
     StatusChecker checker = new StatusChecker(loggerContext);
-    assertTrue(checker.isErrorFree());
+    assertTrue(checker.isErrorFree(0));
   }
 
   void verifyJULLevel(String loggerName, Level expectedLevel) {
@@ -358,7 +363,7 @@ public class JoranConfiguratorTest {
             + "/jul/levelChangePropagator0.xml";
     configure(configFileAsStr);
     StatusChecker checker = new StatusChecker(loggerContext);
-    assertTrue(checker.isErrorFree());
+    assertTrue(checker.isErrorFree(0));
     verifyJULLevel("xx", null);
     verifyJULLevel("a.b.c", Level.WARN);
     verifyJULLevel(Logger.ROOT_LOGGER_NAME, Level.TRACE);
@@ -372,7 +377,7 @@ public class JoranConfiguratorTest {
             + "/jul/levelChangePropagator1.xml";
     configure(configFileAsStr);
     StatusChecker checker = new StatusChecker(loggerContext);
-    assertTrue(checker.isErrorFree());
+    assertTrue(checker.isErrorFree(0));
     verifyJULLevel("xx", Level.INFO);
     verifyJULLevel("a.b.c", Level.WARN);
     verifyJULLevel(Logger.ROOT_LOGGER_NAME, Level.TRACE);
@@ -391,4 +396,15 @@ public class JoranConfiguratorTest {
     configure(configFileAsStr);
   }
 
+  @Test
+  public void lbcore193() throws JoranException {
+    String configFileAsStr = ClassicTestConstants.JORAN_INPUT_PREFIX
+            + "lbcore193.xml";
+    configure(configFileAsStr);
+    StatusPrinter.print(loggerContext);
+    sc.containsException(ScanException.class);
+    sc.containsMatch(Status.ERROR, "Expecting RIGHT_PARENTHESIS token but got null");
+    sc.containsMatch(Status.ERROR, "See also "+ Parser.MISSING_RIGHT_PARENTHESIS);
+  }
+
 }
