@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2009, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -342,6 +342,24 @@ public class TokenStreamTest {
       witness.add(new Token(Token.LITERAL, ")"));
       assertEquals(witness, tl);
     }
+    {
+      List tl = new TokenStream("%a(x\\)").tokenize();
+      List<Token> witness = new ArrayList<Token>();
+      witness.add(Token.PERCENT_TOKEN);
+      witness.add(new Token(Token.COMPOSITE_KEYWORD, "a"));
+      witness.add(new Token(Token.LITERAL, "x)"));
+      assertEquals(witness, tl);
+    }
+    {
+      List tl = new TokenStream("%a\\(x)").tokenize();
+      List<Token> witness = new ArrayList<Token>();
+      witness.add(Token.PERCENT_TOKEN);
+      witness.add(new Token(Token.SIMPLE_KEYWORD, "a"));
+      witness.add(new Token(Token.LITERAL, "(x"));
+      witness.add(new Token(Token.RIGHT_PARENTHESIS));
+
+      assertEquals(witness, tl);
+    }
   }
 
   @Test
