@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2009, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -107,9 +107,9 @@ public class RollingFileAppenderTest extends AbstractAppenderTest<Object> {
 
     rfa.start();
 
-    StatusManager sm = context.getStatusManager();
+    StatusChecker checker = new StatusChecker(context);
     assertFalse(rfa.isStarted());
-    assertEquals(Status.ERROR, sm.getLevel());
+    assertEquals(Status.ERROR, checker.getHighestLevel(0));
   }
 
   @Test
